@@ -1,6 +1,6 @@
 /*
  * rd_stats.c: Read system statistics
- * (C) 1999-2014 by Sebastien GODARD (sysstat <at> orange.fr)
+ * (C) 1999-2015 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
  * This program is free software; you can redistribute it and/or modify it *
@@ -2071,7 +2071,7 @@ void read_bus_usb_dev(struct stats_pwr_usb *st_pwr_usb, int nbr)
 void read_filesystem(struct stats_filesystem *st_filesystem, int nbr)
 {
 	FILE *fp;
-	char line[256], fs_name[MAX_FS_LEN], mountp[128];
+	char line[512], fs_name[MAX_FS_LEN], mountp[256];
 	int fs = 0;
 	struct stats_filesystem *st_filesystem_i;
 	struct statvfs buf;
@@ -2082,12 +2082,26 @@ void read_filesystem(struct stats_filesystem *st_filesystem, int nbr)
 	while ((fgets(line, sizeof(line), fp) != NULL) && (fs < nbr)) {
 		if (line[0] == '/') {
 
-			/* Read current filesystem name and mount point */
-			sscanf(line, "%71s %127s", fs_name, mountp);
+			/* Read current filesystem name */
+			sscanf(line, "%127s", fs_name);
+			/*
+			 * And now read the corresponding mount point.
+			 * Read fs name and mount point in two distinct operations.
+			 * Indeed, if fs name length is greater than 127 chars,
+			 * previous scanf() will read only the first 127 chars, and
+			 * mount point name will be read using the remaining chars
+			 * from the fs name. This will result in a bogus name
+			 * and following statvfs() function will always fail.
+			 */
+			sscanf(strchr(line, ' ') + 1, "%255s", mountp);
 
 			/* Replace octal codes */
 			oct2chr(mountp);
 
+			/*
+			 * It's important to have read the whole mount point name
+			 * for statvfs() to work properly (see above).
+			 */
 			if ((statvfs(mountp, &buf) < 0) || (!buf.f_blocks))
 				continue;
 
@@ -2098,6 +2112,8 @@ void read_filesystem(struct stats_filesystem *st_filesystem, int nbr)
 			st_filesystem_i->f_files  = buf.f_files;
 			st_filesystem_i->f_ffree  = buf.f_ffree;
 			strcpy(st_filesystem_i->fs_name, fs_name);
+			strncpy(st_filesystem_i->mountp, mountp, MAX_FS_LEN);
+			st_filesystem_i->mountp[MAX_FS_LEN - 1] = '\0';
 		}
 	}
 
